==> igniteui-angular-charts-17.2.1.tgz: package/esm5/lib/NegativeVolumeIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { NegativeVolumeIndexIndicatorStrategy } from "./NegativeVolumeIndexIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var NegativeVolumeIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NegativeVolumeIndexIndicator, _super);
    function NegativeVolumeIndexIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NegativeVolumeIndexIndicator.prototype.bg = function () {
        return new NegativeVolumeIndexIndicator();
    };
    NegativeVolumeIndexIndicator.prototype.get_yz = function () {
        return new NegativeVolumeIndexIndicatorStrategy();
    };
    Object.defineProperty(NegativeVolumeIndexIndicator.prototype, "yz", {
        get: function () {
            return this.get_yz();
        },
        enumerable: false,
        configurable: true
    });
    NegativeVolumeIndexIndicator.prototype.get_zc = function () {
        return NegativeVolumeIndexIndicator.$;
    };
    Object.defineProperty(NegativeVolumeIndexIndicator.prototype, "zc", {
        get: function () {
            return this.get_zc();
        },
        enumerable: false,
        configurable: true
    });
    NegativeVolumeIndexIndicator.$t = markType(NegativeVolumeIndexIndicator, 'NegativeVolumeIndexIndicator', StrategyBasedIndicator.$);
    return NegativeVolumeIndexIndicator;
}(StrategyBasedIndicator));
export { NegativeVolumeIndexIndicator };

==> igniteui-angular-charts-17.3.0.tgz: package/esm5/lib/NegativeVolumeIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { NegativeVolumeIndexIndicatorStrategy } from "./NegativeVolumeIndexIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var NegativeVolumeIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NegativeVolumeIndexIndicator, _super);
    function NegativeVolumeIndexIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NegativeVolumeIndexIndicator.prototype.bc = function () {
        return new NegativeVolumeIndexIndicator();
    };
    NegativeVolumeIndexIndicator.prototype.get_y0 = function () {
        return new NegativeVolumeIndexIndicatorStrategy();
    };
    Object.defineProperty(NegativeVolumeIndexIndicator.prototype, "y0", {
        get: function () {
            return this.get_y0();
        },
        enumerable: false,
        configurable: true
    });
    NegativeVolumeIndexIndicator.prototype.get_zd = function () {
        return NegativeVolumeIndexIndicator.$;
    };
    Object.defineProperty(NegativeVolumeIndexIndicator.prototype, "zd", {
        get: function () {
            return this.get_zd();
        },
        enumerable: false,
        configurable: true
    });
    NegativeVolumeIndexIndicator.$t = markType(NegativeVolumeIndexIndicator, 'NegativeVolumeIndexIndicator', StrategyBasedIndicator.$);
    return NegativeVolumeIndexIndicator;
}(StrategyBasedIndicator));
export { NegativeVolumeIndexIndicator };
